@@ -27,14 +27,16 @@ async def bili_keyword(group_id, text):
                     break
 
         # 获取视频详细信息
-        if "bangumi" in url:
+        if "view?" in url:
+            msg, vurl = await video_detail(url, page)
+        elif "bangumi" in url:
             msg, vurl = await bangumi_detail(url)
-        elif "live.bilibili.com" in url:
+        elif "xlive" in url:
             msg, vurl = await live_detail(url)
         elif "article" in url:
             msg, vurl = await article_detail(url)
         else:
-            msg, vurl = await video_detail(url, page)
+            msg, vurl = await dynamic_detail(url)
 
         # 避免多个机器人解析重复推送
         if group_id not in analysis_stat:
@@ -74,6 +76,7 @@ async def extract(text: str):
         cvid = re.compile(r"(cv|/read/(mobile|native)(/|\?id=))(\d+)", re.I).search(
             text
         )
+        dynamic_id = re.compile(r"t.bilibili.com/(\d+)", re.I).search(text)
         if bvid:
             url = f"https://api.bilibili.com/x/web-interface/view?bvid={bvid[0]}"
         elif aid:
@@ -90,6 +93,8 @@ async def extract(text: str):
             url = f"https://api.live.bilibili.com/xlive/web-room/v1/index/getInfoByRoom?room_id={room_id[2]}"
         elif cvid:
             url = f"https://api.bilibili.com/x/article/viewinfo?id={cvid[4]}&mobi_app=pc&from=web"
+        elif dynamic_id:
+            url = f"https://api.vc.bilibili.com/dynamic_svr/v1/dynamic_svr/get_dynamic_detail?dynamic_id={dynamic_id[1]}"
         return url, page
     except:
         return None, None
@@ -126,7 +131,7 @@ async def video_detail(url, page):
             p = int(page[len("?p=") :])
             if p <= len(res["pages"]):
                 vurl += page + ""
-                part = res['pages'][p-1]['part']
+                part = res["pages"][p - 1]["part"]
                 if part != res["title"]:
                     title += f"小标题：{part}\n"
         tname = f"类型：{res['tname']} | UP：{res['owner']['name']}\n"
@@ -255,3 +260,40 @@ async def article_detail(url):
     except Exception as e:
         msg = "专栏解析出错--Error: {}".format(type(e))
         return msg, None
+
+
+async def dynamic_detail(url):
+    try:
+        async with aiohttp.request(
+            "GET", url, timeout=aiohttp.client.ClientTimeout(10)
+        ) as resp:
+            res = await resp.json()
+            res = res["data"]["card"]
+        card = json.loads(res["card"])
+        dynamic_id = res["desc"]["dynamic_id"]
+        vurl = f"https://t.bilibili.com/{dynamic_id}\n"
+        item = card.get("item")
+        if not item:
+            return "动态不存在文字内容", vurl
+        content = item.get("description")
+        if not content:
+            content = item.get("content")
+        content = content.replace("\r", "\n")
+        if len(content) > 250:
+            content = content[:250] + "......"
+        pics = item.get("pictures")
+        if pics:
+            content += f"\nPS：动态中包含{len(pics)}张图片"
+        origin = card.get("origin")
+        if origin:
+            jorigin = json.loads(origin)
+            short_link = jorigin.get("short_link")
+            if short_link:
+                content += f"\n动态包含转发视频{short_link}"
+            else:
+                content += f"\n动态包含转发其他动态"
+        msg = str(vurl) + str(content)
+        return msg, vurl
+    except Exception as e:
+        msg = "动态解析出错--Error: {}".format(type(e))
+        return msg, None
\ No newline at end of file
